@@ -3,7 +3,7 @@ use std::io::Result;
 use crate::deps;
 use crate::tree::{self, InputFmt};
 use crate::utils;
-use clap::{crate_name, App, AppSettings, Arg, ArgMatches};
+use clap::{crate_description, crate_name, App, AppSettings, Arg, ArgMatches};
 
 use log::LevelFilter;
 use log4rs::append::console::ConsoleAppender;
@@ -12,15 +12,15 @@ use log4rs::config::{Appender, Config, Root};
 use log4rs::encode::pattern::PatternEncoder;
 
 fn get_args(version: &str) -> ArgMatches {
-    App::new("myte")
+    App::new(crate_name!())
         .version(version)
-        .about("A tool for phylogenomic tree building")
+        .about(crate_description!())
         .author("Heru Handika <hhandi1@lsu.edu>")
         .setting(AppSettings::SubcommandRequiredElseHelp)
         .subcommand(App::new("check").about("Check dependencies"))
         .subcommand(
             App::new("gene")
-                .about("Multi-core gene tree estimation using IQ-Tree")
+                .about("Batch gene tree estimation using IQ-Tree")
                 .arg(
                     Arg::with_name("dir")
                         .short("d")
@@ -52,7 +52,7 @@ fn get_args(version: &str) -> ArgMatches {
         .subcommand(
             App::new("auto")
                 .about(
-                    "Auto estimate species tree, gene trees, and gene and site concordance factors",
+                    "Estimate species tree, gene trees, gene and site concordance factors, and MSC tree",
                 )
                 .arg(
                     Arg::with_name("dir")
@@ -117,10 +117,7 @@ pub fn parse_cli(version: &str) {
     match args.subcommand() {
         ("auto", Some(auto_matches)) => parse_auto_cli(auto_matches, &version),
         ("gene", Some(gene_matches)) => parse_gene_cli(gene_matches, &version),
-        ("check", Some(_)) => {
-            display_app_info(&version);
-            deps::check_dependencies();
-        }
+        ("check", Some(_)) => display_app_info(&version),
         ("deps", Some(deps_matches)) => parse_deps_cli(deps_matches),
         _ => unreachable!(),
     }
@@ -228,9 +225,10 @@ fn print_msc_tree_header(len: usize) {
 
 fn display_app_info(version: &str) {
     log::info!("{} v{}", crate_name!(), version);
-    log::info!("Genomics tools for phylogenetic tree estimation");
+    log::info!("{}", crate_description!());
     log::info!("Developed by Heru Handika\n");
     utils::get_system_info();
+    deps::check_dependencies();
 }
 
 fn print_complete() {
